==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HeaderMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HeaderMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Conditions required to match a header
 * @property exactMatch Exact value of the header
 * @property header Name of the header
 * @property prefixMatch Prefix value of the header
 * @property regexMatch Regex value of the header
 * @property suffixMatch Suffix value of the header
 */
public data class HeaderMatchArgs(
    public val exactMatch: Output<String>? = null,
    public val `header`: Output<String>? = null,
    public val prefixMatch: Output<String>? = null,
    public val regexMatch: Output<String>? = null,
    public val suffixMatch: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HeaderMatchArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HeaderMatchArgs =
        com.pulumi.azurenative.app.inputs.HeaderMatchArgs.builder()
            .exactMatch(exactMatch?.applyValue({ args0 -> args0 }))
            .`header`(`header`?.applyValue({ args0 -> args0 }))
            .prefixMatch(prefixMatch?.applyValue({ args0 -> args0 }))
            .regexMatch(regexMatch?.applyValue({ args0 -> args0 }))
            .suffixMatch(suffixMatch?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HeaderMatchArgs].
 */
@PulumiTagMarker
public class HeaderMatchArgsBuilder internal constructor() {
    private var exactMatch: Output<String>? = null

    private var `header`: Output<String>? = null

    private var prefixMatch: Output<String>? = null

    private var regexMatch: Output<String>? = null

    private var suffixMatch: Output<String>? = null

    /**
     * @param value Exact value of the header
     */
    @JvmName("psamdiqgwoqtwoxa")
    public suspend fun exactMatch(`value`: Output<String>) {
        this.exactMatch = value
    }

    /**
     * @param value Name of the header
     */
    @JvmName("gwvucprodhkmwvku")
    public suspend fun `header`(`value`: Output<String>) {
        this.`header` = value
    }

    /**
     * @param value Prefix value of the header
     */
    @JvmName("ldtsveadefmqmaof")
    public suspend fun prefixMatch(`value`: Output<String>) {
        this.prefixMatch = value
    }

    /**
     * @param value Regex value of the header
     */
    @JvmName("yxvccukrdrrdjyap")
    public suspend fun regexMatch(`value`: Output<String>) {
        this.regexMatch = value
    }

    /**
     * @param value Suffix value of the header
     */
    @JvmName("aapfscpkwcwgawqw")
    public suspend fun suffixMatch(`value`: Output<String>) {
        this.suffixMatch = value
    }

    /**
     * @param value Exact value of the header
     */
    @JvmName("rymamiodmstsrqhu")
    public suspend fun exactMatch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exactMatch = mapped
    }

    /**
     * @param value Name of the header
     */
    @JvmName("xlbpywutrakuaovh")
    public suspend fun `header`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`header` = mapped
    }

    /**
     * @param value Prefix value of the header
     */
    @JvmName("hcpnikcddtfldjed")
    public suspend fun prefixMatch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.prefixMatch = mapped
    }

    /**
     * @param value Regex value of the header
     */
    @JvmName("bivrqcvjmawwihep")
    public suspend fun regexMatch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regexMatch = mapped
    }

    /**
     * @param value Suffix value of the header
     */
    @JvmName("qirfwowcyogbofmo")
    public suspend fun suffixMatch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.suffixMatch = mapped
    }

    internal fun build(): HeaderMatchArgs = HeaderMatchArgs(
        exactMatch = exactMatch,
        `header` = `header`,
        prefixMatch = prefixMatch,
        regexMatch = regexMatch,
        suffixMatch = suffixMatch,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HeaderMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HeaderMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Conditions required to match a header
 * @property exactMatch Exact value of the header
 * @property header Name of the header
 * @property prefixMatch Prefix value of the header
 * @property regexMatch Regex value of the header
 * @property suffixMatch Suffix value of the header
 */
public data class HeaderMatchArgs(
    public val exactMatch: Output<String>? = null,
    public val `header`: Output<String>? = null,
    public val prefixMatch: Output<String>? = null,
    public val regexMatch: Output<String>? = null,
    public val suffixMatch: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HeaderMatchArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HeaderMatchArgs =
        com.pulumi.azurenative.app.inputs.HeaderMatchArgs.builder()
            .exactMatch(exactMatch?.applyValue({ args0 -> args0 }))
            .`header`(`header`?.applyValue({ args0 -> args0 }))
            .prefixMatch(prefixMatch?.applyValue({ args0 -> args0 }))
            .regexMatch(regexMatch?.applyValue({ args0 -> args0 }))
            .suffixMatch(suffixMatch?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HeaderMatchArgs].
 */
@PulumiTagMarker
public class HeaderMatchArgsBuilder internal constructor() {
    private var exactMatch: Output<String>? = null

    private var `header`: Output<String>? = null

    private var prefixMatch: Output<String>? = null

    private var regexMatch: Output<String>? = null

    private var suffixMatch: Output<String>? = null

    /**
     * @param value Exact value of the header
     */
    @JvmName("hfbaphhusjielyib")
    public suspend fun exactMatch(`value`: Output<String>) {
        this.exactMatch = value
    }

    /**
     * @param value Name of the header
     */
    @JvmName("pfrpjwixwlcskwfp")
    public suspend fun `header`(`value`: Output<String>) {
        this.`header` = value
    }

    /**
     * @param value Prefix value of the header
     */
    @JvmName("wspmfvneqyptfavs")
    public suspend fun prefixMatch(`value`: Output<String>) {
        this.prefixMatch = value
    }

    /**
     * @param value Regex value of the header
     */
    @JvmName("wxhvmdemokgxfxwm")
    public suspend fun regexMatch(`value`: Output<String>) {
        this.regexMatch = value
    }

    /**
     * @param value Suffix value of the header
     */
    @JvmName("gjbikepwwqlmspyl")
    public suspend fun suffixMatch(`value`: Output<String>) {
        this.suffixMatch = value
    }

    /**
     * @param value Exact value of the header
     */
    @JvmName("nhwedpktehrmrqns")
    public suspend fun exactMatch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exactMatch = mapped
    }

    /**
     * @param value Name of the header
     */
    @JvmName("qtdpiygtlslhwqlx")
    public suspend fun `header`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`header` = mapped
    }

    /**
     * @param value Prefix value of the header
     */
    @JvmName("qvsxwqagegyeicew")
    public suspend fun prefixMatch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.prefixMatch = mapped
    }

    /**
     * @param value Regex value of the header
     */
    @JvmName("npgrfuawliplqqqj")
    public suspend fun regexMatch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regexMatch = mapped
    }

    /**
     * @param value Suffix value of the header
     */
    @JvmName("lctgbjrrxqoouyuk")
    public suspend fun suffixMatch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.suffixMatch = mapped
    }

    internal fun build(): HeaderMatchArgs = HeaderMatchArgs(
        exactMatch = exactMatch,
        `header` = `header`,
        prefixMatch = prefixMatch,
        regexMatch = regexMatch,
        suffixMatch = suffixMatch,
    )
}
